@@ -1,7 +1,6 @@
-from PyObjCTools.TestSupport import *
-
-import StoreKit
 import objc
+import StoreKit  # noqa: F401
+from PyObjCTools.TestSupport import TestCase
 
 
 class TestSKProductsRequest(TestCase):
@@ -9,7 +8,3 @@ class TestSKProductsRequest(TestCase):
         self.assertIsInstance(
             objc.protocolNamed("SKProductsRequestDelegate"), objc.formal_protocol
         )
-
-
-if __name__ == "__main__":
-    main()
